
import re
from odoo.tools import sql
from odoo.upgrade import util


def migrate(cr, version):
    # remove deprecated views
    util.remove_view(cr, "openerp_website.o_tab_nav_options")

    # update deprecated geoip dict api usage on demo pages
    cr.execute("SELECT id FROM ir_ui_view WHERE arch_db->>'en_US' ilike %s", (r"%request.geoip%",))
    view_ids = [row[0] for row in cr.fetchall()]
    for view_id in view_ids:
        with util.edit_view(cr, view_id=view_id) as arch:
            for node in arch.xpath("//*[@*[contains(., 'request.geoip')]]"):
                for attr, attr_value in node.attrib.items():
                    if "request.geoip" not in attr_value:
                        continue
                    attr_value = attr_value.replace(r"(request.geoip\s+or\s+{})", "request.geoip")
                    attr_value = re.sub(
                        r"""request.geoip.get\(['"]country_code['"][^\)]*\)""",
                        "request.geoip.country_code",
                        attr_value
                    )
                    node.attrib[attr] = attr_value

    # in saas~16.3, website_event introduced a "company_name" field which serve
    # the same purpose as our custom "organization" field, so use the standard
    # field.
    util.remove_column(cr, "event_registration", "company_name")
    sql.rename_column(cr, "event_registration", "organization", "company_name")
    util.update_field_usage(cr, "event.registration", "organization", "company_name")  # filters, exports, ...
    util.remove_field(cr, "event.registration", "organization")
